//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Tile](index.md)/[compareTo](compare-to.md)

# compareTo

[common]\
open operator override fun [compareTo](compare-to.md)(other: [Tile](index.md)): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)
